@@ -554,7 +554,7 @@ font_hash_key_for_context (PangoFcFontMap *fcfontmap,
     key->context_key = NULL;
 }
 
-/* Add a mapping from xfont->font_pattern to xfont */
+/* Add a mapping from fcfont->font_pattern to fcfont */
 static void
 pango_fc_font_map_add (PangoFcFontMap *fcfontmap,
 		       PangoContext   *context,
@@ -1827,7 +1827,7 @@ pango_fc_face_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       const GTypeInfo object_info =
       {
@@ -2030,7 +2030,7 @@ pango_fc_family_get_type (void)
 {
   static GType object_type = 0;
 
-  if (!object_type)
+  if (G_UNLIKELY (!object_type))
     {
       const GTypeInfo object_info =
       {
